4. Installation — pvlab 0.1.0.dev1 documentation

# 4. Installation

## From the Python installer

From pip, proceed as follows:

First of all, if a virtual environment (e.g. myvenv) has been previously created, and it is the desired working environment, it should be activated. You can do it by typing from Terminal (in MacOS/Unix):

`source myenv/bin/activate`

or, from a system console in Windows platforms:

`.\myvenv\Scripts\activate`

Also, the python installer `pip` should be updated:

`python -m pip install --upgrade pip`

Note

Be sure the python root folder is present in the system path.

Finally, the `pvlab` package can be installed:

`python -m pip install --upgrade pvlab`

## From the Anaconda IDE

When using the Anaconda IDE, `pvlab` can be installed both by typing:

`conda install pvlab`

or, alternatively, from the Anaconda Navigator, following the sequence: Environments > Search Packages, and selecting the `pvlab` package.